@@ -1,3 +1,6 @@
+#!/bin/bash
+# This script os a helper script for checking if the pip-published 
+# package works.
 
 cacha_version = $1
 pip install cacha==$(cacha_version)
@@ -5,14 +8,17 @@ pip install cacha==$(cacha_version)
 
 python - << EOF
 import cacha
-string = "This is a long string"
+string = "This should be split"
+
 
 def split(string: str) -> list:
     return string.split()
 
+
 cacha.cache(split, (string,))
 
-cached_string = cacha.cache(split, (string,))
+result = cacha.cache(split, (string,))
+
+print(result)
 
 EOF
-
