@@ -31,7 +31,7 @@ def test_numpy():
 
 def test_raw_text():
     """Test caching for string object."""
-    string = "This is a long string"
+    string = "This should be split"
 
     def split(string: str) -> list:
         return string.split()
@@ -40,4 +40,4 @@ def test_raw_text():
 
     cached = cacha.cache(split, (string,))
 
-    assert len(cached) == 5
+    assert len(cached) == 4
